@@ -206,13 +206,13 @@ typedef hash_string_string omc_CommandLineOverrides;
 typedef hash_string_long omc_CommandLineOverridesUses;
 
 // function to handle command line settings override
-void doOverride(omc_ModelInput *mi, MODEL_DATA* modelData, const char* override, const char* overrideFile);
+modelica_boolean doOverride(omc_ModelInput *mi, MODEL_DATA *modelData, const char *override, const char *overrideFile);
 
 static const double REAL_MIN = -DBL_MAX;
 static const double REAL_MAX = DBL_MAX;
-static const double INTEGER_MIN = (((modelica_integer)-1)<<(8*sizeof(modelica_integer)-1));
+static const double INTEGER_MIN = (double)MODELICA_INT_MIN;
 /* Avoid integer overflow */
-static const double INTEGER_MAX = -((((modelica_integer)-1)<<(8*sizeof(modelica_integer)-1))+1);
+static const double INTEGER_MAX = (double)MODELICA_INT_MAX;
 
 /* reads double value from a string */
 static void read_value_real(const char *s, modelica_real* res, modelica_real default_value);
@@ -376,6 +376,7 @@ static void read_var_info(omc_ScalarVariable *v, VAR_INFO *info)
 static void read_var_attribute_real(omc_ScalarVariable *v, REAL_ATTRIBUTE *attribute)
 {
   const char *unit = NULL;
+  const char *displayUnit = NULL;
   read_value_real(findHashStringStringEmpty(v,"start"), &(attribute->start), 0.0);
   read_value_bool(findHashStringString(v,"fixed"), (modelica_boolean*)&(attribute->fixed));
   read_value_bool(findHashStringString(v,"useNominal"), (modelica_boolean*)&(attribute->useNominal));
@@ -385,6 +386,10 @@ static void read_var_attribute_real(omc_ScalarVariable *v, REAL_ATTRIBUTE *attri
   read_value_string(findHashStringStringEmpty(v,"unit"), &unit);
   attribute->unit = mmc_mk_scon_persist(unit); /* this function returns a copy, so unit can be freed */
   free((char*)unit);
+  // read displayUnit
+  read_value_string(findHashStringStringEmpty(v,"displayUnit"), &displayUnit);
+  attribute->displayUnit = mmc_mk_scon_persist(displayUnit); /* this function returns a copy, so unit can be freed */
+  free((char*)displayUnit);
 
   infoStreamPrint(LOG_DEBUG, 0, "Real %s(start=%g, fixed=%s, %snominal=%g%s, min=%g, max=%g)", findHashStringString(v,"name"), attribute->start, (attribute->fixed)?"true":"false", (attribute->useNominal)?"":"{", attribute->nominal, attribute->useNominal?"":"}", attribute->min, attribute->max);
 }
@@ -527,7 +532,7 @@ void read_input_xml(MODEL_DATA* modelData,
   // deal with override
   override = omc_flagValue[FLAG_OVERRIDE];
   overrideFile = omc_flagValue[FLAG_OVERRIDE_FILE];
-  doOverride(&mi, modelData, override, overrideFile);
+  modelica_boolean reCalcStepSize = doOverride(&mi, modelData, override, overrideFile);
 
   /* read all the DefaultExperiment values */
   infoStreamPrint(LOG_SIMULATION, 1, "read all the DefaultExperiment values:");
@@ -538,7 +543,15 @@ void read_input_xml(MODEL_DATA* modelData,
   read_value_real(findHashStringString(mi.de,"stopTime"), &(simulationInfo->stopTime), 1.0);
   infoStreamPrint(LOG_SIMULATION, 0, "stopTime = %g", simulationInfo->stopTime);
 
-  read_value_real(findHashStringString(mi.de,"stepSize"), &(simulationInfo->stepSize), (simulationInfo->stopTime - simulationInfo->startTime) / 500);
+  if (reCalcStepSize) {
+    simulationInfo->stepSize = (simulationInfo->stopTime - simulationInfo->startTime) / 500;
+    warningStreamPrint(LOG_STDOUT, 1, "Start or stop time was overwritten, but no new integrator step size was provided.");
+    infoStreamPrint(LOG_STDOUT, 0, "Re-calculating step size for 500 intervals.");
+    infoStreamPrint(LOG_STDOUT, 0, "Add `stepSize=<value>` to `-override=` or override file to silence this warning.");
+    messageClose(LOG_STDOUT);
+  } else {
+    read_value_real(findHashStringString(mi.de,"stepSize"), &(simulationInfo->stepSize), (simulationInfo->stopTime - simulationInfo->startTime) / 500);
+  }
   infoStreamPrint(LOG_SIMULATION, 0, "stepSize = %g", simulationInfo->stepSize);
 
   read_value_real(findHashStringString(mi.de,"tolerance"), &(simulationInfo->tolerance), 1e-5);
@@ -598,8 +611,46 @@ void read_input_xml(MODEL_DATA* modelData,
     EXIT(-1);
   }
 
-  /* read all static data from File for every variable */
 
+/* general check for filtering the output for a variable
+ * defined here to be reused everywhere
+ * the check is like this:
+ * - we filter if isProtected (protected variables)
+ * - we filter if annotation(HideResult=true)
+ * - we emit (remove filtering) if emitProtected && isProtected
+ * - we emit (remove filtering) if ignoreHideResult && annotation(HideResult=true)
+ */
+#define setFilterOuput(v, s, n) \
+{ \
+  int ep = omc_flag[FLAG_EMIT_PROTECTED]; \
+  int ihr = omc_flag[FLAG_IGNORE_HIDERESULT]; \
+  const char *ipstr = findHashStringString((v), "isProtected"); \
+  const char *hrstr = findHashStringString((v), "hideResult"); \
+  int ipcmptrue = (0 == strcmp(ipstr, "true")); \
+  int hrcmptrue = (0 == strcmp(hrstr, "true")); \
+  if (ipcmptrue) \
+  { \
+    infoStreamPrint(LOG_DEBUG, 0, "filtering protected variable %s", (n)); \
+    (s).filterOutput = 1; \
+  } \
+  if (hrcmptrue) \
+  { \
+    infoStreamPrint(LOG_DEBUG, 0, "filtering variable %s due to HideResult annotation", (n)); \
+    (s).filterOutput = 1; \
+  } \
+  if (ep && ipcmptrue) \
+  { \
+    infoStreamPrint(LOG_DEBUG, 0, "emitting protected variable %s due to flag %s", (n), omc_flagValue[FLAG_EMIT_PROTECTED]); \
+    (s).filterOutput = 0; \
+  } \
+  if (ihr && hrcmptrue) \
+  { \
+    infoStreamPrint(LOG_DEBUG, 0, "emitting variable %s with HideResult=true annotation due to flag %s", (n), omc_flagValue[FLAG_IGNORE_HIDERESULT]); \
+    (s).filterOutput = 0; \
+  } \
+}
+
+/* read all static data from File for every variable */
 #define READ_VARIABLES(out, in, attributeKind, read_var_attribute, debugName, start, nStates, mapAlias) \
   infoStreamPrint(LOG_DEBUG, 1, "read xml file for %s", debugName); \
   for(i = 0; i < nStates; i++) \
@@ -610,16 +661,7 @@ void read_input_xml(MODEL_DATA* modelData,
     omc_ScalarVariable *v = *findHashLongVar(in, i); \
     read_var_info(v, info); \
     read_var_attribute(v, attribute); \
-    if (!omc_flag[FLAG_EMIT_PROTECTED] && 0 == strcmp(findHashStringString(v, "isProtected"), "true") && 0 == strcmp(findHashStringString(v, "hideResult"), "true")) \
-    { \
-      infoStreamPrint(LOG_DEBUG, 0, "filtering protected variable %s", info->name); \
-      out[j].filterOutput = 1; \
-    } \
-    else if (!omc_flag[FLAG_IGNORE_HIDERESULT] && 0 == strcmp(findHashStringString(v, "hideResult"), "true") && 0 == strcmp(findHashStringString(v, "isProtected"), "false")) \
-    { \
-      infoStreamPrint(LOG_DEBUG, 0, "filtering variable %s due to HideResult annotation", info->name); \
-      out[j].filterOutput = 1; \
-    } \
+    setFilterOuput(v, out[j], info->name); \
     addHashStringLong(&mapAlias, info->name, j); /* create a mapping for Alias variable to get the correct index */ \
     debugStreamPrint(LOG_DEBUG, 0, "real %s: mapAlias[%s] = %ld", debugName, info->name, (long) j); \
     if (omc_flag[FLAG_IDAS] && 0 == strcmp(debugName, "real sensitivities")) \
@@ -670,16 +712,7 @@ void read_input_xml(MODEL_DATA* modelData,
     }
     infoStreamPrint(LOG_DEBUG, 0, "read for %s negated %d from setup file", modelData->realAlias[i].info.name, modelData->realAlias[i].negate);
 
-    if (!omc_flag[FLAG_EMIT_PROTECTED] && 0 == strcmp(findHashStringString(*findHashLongVar(mi.rAli,i), "isProtected"), "true") && 0 == strcmp(findHashStringString(*findHashLongVar(mi.rAli,i), "hideResult"), "true"))
-    {
-      infoStreamPrint(LOG_DEBUG, 0, "filtering protected variable %s", modelData->realAlias[i].info.name);
-      modelData->realAlias[i].filterOutput = 1;
-    }
-    else if (!omc_flag[FLAG_IGNORE_HIDERESULT] && 0 == strcmp(findHashStringString(*findHashLongVar(mi.rAli,i), "hideResult"), "true") && 0 == strcmp(findHashStringString(*findHashLongVar(mi.rAli,i), "isProtected"), "false"))
-    {
-      infoStreamPrint(LOG_DEBUG, 0, "filtering variable %s due to HideResult annotation", modelData->realAlias[i].info.name);
-      modelData->realAlias[i].filterOutput = 1;
-    }
+    setFilterOuput(*findHashLongVar(mi.rAli,i), modelData->realAlias[i], modelData->realAlias[i].info.name);
 
     free((char*)aliasTmp);
     aliasTmp = NULL;
@@ -725,16 +758,8 @@ void read_input_xml(MODEL_DATA* modelData,
 
     infoStreamPrint(LOG_DEBUG, 0, "read for %s negated %d from setup file",modelData->integerAlias[i].info.name,modelData->integerAlias[i].negate);
 
-    if (!omc_flag[FLAG_EMIT_PROTECTED] && 0 == strcmp(findHashStringString(*findHashLongVar(mi.iAli,i), "isProtected"), "true") && 0 == strcmp(findHashStringString(*findHashLongVar(mi.iAli,i), "hideResult"), "true"))
-    {
-      infoStreamPrint(LOG_DEBUG, 0, "filtering protected variable %s", modelData->integerAlias[i].info.name);
-      modelData->integerAlias[i].filterOutput = 1;
-    }
-    else if (!omc_flag[FLAG_IGNORE_HIDERESULT] && 0 == strcmp(findHashStringString(*findHashLongVar(mi.iAli,i), "hideResult"), "true") && 0 == strcmp(findHashStringString(*findHashLongVar(mi.iAli,i), "isProtected"), "false"))
-    {
-      infoStreamPrint(LOG_DEBUG, 0, "filtering variable %s due to HideResult annotation", modelData->integerAlias[i].info.name);
-      modelData->integerAlias[i].filterOutput = 1;
-    }
+    setFilterOuput(*findHashLongVar(mi.iAli,i), modelData->integerAlias[i], modelData->integerAlias[i].info.name);
+
     free((char*)aliasTmp);
     aliasTmp = NULL;
     read_value_string(findHashStringString(*findHashLongVar(mi.iAli,i),"aliasVariable"), &aliasTmp);
@@ -777,16 +802,8 @@ void read_input_xml(MODEL_DATA* modelData,
 
     infoStreamPrint(LOG_DEBUG, 0, "read for %s negated %d from setup file", modelData->booleanAlias[i].info.name, modelData->booleanAlias[i].negate);
 
-    if (!omc_flag[FLAG_EMIT_PROTECTED] && 0 == strcmp(findHashStringString(*findHashLongVar(mi.bAli,i), "isProtected"), "true") && 0 == strcmp(findHashStringString(*findHashLongVar(mi.bAli,i), "hideResult"), "true"))
-    {
-      infoStreamPrint(LOG_DEBUG, 0, "filtering protected variable %s", modelData->booleanAlias[i].info.name);
-      modelData->booleanAlias[i].filterOutput = 1;
-    }
-    else if (!omc_flag[FLAG_IGNORE_HIDERESULT] && 0 == strcmp(findHashStringString(*findHashLongVar(mi.bAli,i), "hideResult"), "true") && 0 == strcmp(findHashStringString(*findHashLongVar(mi.bAli,i), "isProtected"), "false"))
-    {
-      infoStreamPrint(LOG_DEBUG, 0, "filtering variable %s due to HideResult annotation", modelData->booleanAlias[i].info.name);
-      modelData->booleanAlias[i].filterOutput = 1;
-    }
+    setFilterOuput(*findHashLongVar(mi.bAli,i), modelData->booleanAlias[i], modelData->booleanAlias[i].info.name);
+
     free((char*)aliasTmp);
     aliasTmp = NULL;
     read_value_string(findHashStringString(*findHashLongVar(mi.bAli,i),"aliasVariable"), &aliasTmp);
@@ -828,16 +845,7 @@ void read_input_xml(MODEL_DATA* modelData,
     }
     infoStreamPrint(LOG_DEBUG, 0, "read for %s negated %d from setup file", modelData->stringAlias[i].info.name, modelData->stringAlias[i].negate);
 
-    if (!omc_flag[FLAG_EMIT_PROTECTED] && 0 == strcmp(findHashStringString(*findHashLongVar(mi.sAli,i), "isProtected"), "true") && 0 == strcmp(findHashStringString(*findHashLongVar(mi.sAli,i), "hideResult"), "true"))
-    {
-      infoStreamPrint(LOG_DEBUG, 0, "filtering protected variable %s", modelData->stringAlias[i].info.name);
-      modelData->stringAlias[i].filterOutput = 1;
-    }
-    else if (!omc_flag[FLAG_IGNORE_HIDERESULT] && 0 == strcmp(findHashStringString(*findHashLongVar(mi.sAli,i), "hideResult"), "true") && 0 == strcmp(findHashStringString(*findHashLongVar(mi.sAli,i), "isProtected"), "false"))
-    {
-      infoStreamPrint(LOG_DEBUG, 0, "filtering variable %s due to HideResult annotation", modelData->stringAlias[i].info.name);
-      modelData->stringAlias[i].filterOutput = 1;
-    }
+    setFilterOuput(*findHashLongVar(mi.sAli,i), modelData->stringAlias[i], modelData->stringAlias[i].info.name);
 
     free((char*)aliasTmp);
     aliasTmp = NULL;
@@ -941,11 +949,24 @@ static const char* getOverrideValue(omc_CommandLineOverrides *mOverrides, omc_Co
   return findHashStringString(mOverrides, name);
 }
 
-void doOverride(omc_ModelInput *mi, MODEL_DATA *modelData, const char *override, const char *overrideFile)
+/**
+ * @brief Read override values from simulation flags `-override` and `-overrideFile` and update variables.
+ *
+ * Return if step sizes needs to be re-calculated because start or stop time was changed, but step size wasn't changed.
+ *
+ * @param mi                    Model input from info XML file.
+ * @param modelData             Pointer to model data containing variable values to override.
+ * @param overrideFile          Path to override file given by `-overrideFile`.
+ * @return modelica_boolean     True if integrator step size should be re-caclualted.
+ */
+modelica_boolean doOverride(omc_ModelInput *mi, MODEL_DATA *modelData, const char *override, const char *overrideFile)
 {
   omc_CommandLineOverrides *mOverrides = NULL;
   omc_CommandLineOverridesUses *mOverridesUses = NULL, *it = NULL, *ittmp = NULL;
   mmc_sint_t i;
+  modelica_boolean changedStartStop = 0 /* false */;
+  modelica_boolean changedStepSize = 0 /* false */;
+  modelica_boolean reCalcStepSize = 0 /* false */;
   char* overrideStr1 = NULL, *overrideStr2 = NULL, *overrideStr = NULL;
   if((override != NULL) && (overrideFile != NULL)) {
     infoStreamPrint(LOG_SOLVER, 0, "using -override=%s and -overrideFile=%s", override, overrideFile);
@@ -1080,12 +1101,20 @@ void doOverride(omc_ModelInput *mi, MODEL_DATA *modelData, const char *override,
       free(overrideStr2);
     }
 
-    // now we have all overrides in mOverrides, override mi now
+    // Now we have all overrides in mOverrides, override mi now
+    // Also check if we need to re-calculate stepSize (start / stop time changed, but stepSize not)
     for (i=0; i<sizeof(strs)/sizeof(char*); i++) {
       if (findHashStringStringNull(mOverrides, strs[i])) {
         addHashStringString(&mi->de, strs[i], getOverrideValue(mOverrides, &mOverridesUses, strs[i]));
+        if (i==1 /* startTime */ || i ==2 /* stopTime */ ) {
+          changedStartStop = 1 /* true */;
+        }
+        if (i==3 /* stepSize */) {
+          changedStepSize = 1 /* true */;
+        }
       }
     }
+    reCalcStepSize = changedStartStop && !changedStepSize;
 
     #define CHECK_OVERRIDE(v,b) \
       if (findHashStringStringNull(mOverrides, findHashStringString(*findHashLongVar(mi->v,i),"name"))) { \
@@ -1158,6 +1187,8 @@ void doOverride(omc_ModelInput *mi, MODEL_DATA *modelData, const char *override,
   } else {
     infoStreamPrint(LOG_SOLVER, 0, "NO override given on the command line.");
   }
+
+  return reCalcStepSize;
 }
 
 void parseVariableStr(char* variableStr)
