@@ -356,9 +356,13 @@ typedef struct NONLINEAR_SYSTEM_DATA
   NLS_SOLVER_STATUS solved;            /* Specifiex if the NLS could be solved (with less accuracy) or failed */
   modelica_real lastTimeSolved;        /* save last successful solved point in time */
 
+  modelica_boolean logActive;          /* Specifies whether LOG_XXX should print for this system.
+                                          false if `-lv_system` is specified but equationIndex is not in the list, else true */
+
   /* statistics */
   unsigned long numberOfCall;          /* number of solving calls of this system */
   unsigned long numberOfFEval;         /* number of function evaluations of this system */
+  unsigned long numberOfFailures;      /* number of times solving calls of this system failed */
   unsigned long numberOfJEval;         /* number of jacobian evaluations of this system */
   unsigned long numberOfIterations;    /* number of iteration of non-linear solvers of this system */
   double totalTime;                    /* save the totalTime */
@@ -385,6 +389,7 @@ typedef struct LINEAR_SYSTEM_THREAD_DATA
 
   /* Statistics for each thread */
   unsigned long numberOfCall;          /* number of solving calls of this system */
+  unsigned long numberOfFailures;      /* number of times solving calls of this system failed */
   unsigned long numberOfJEval;         /* number of jacobian evaluations of this system */
   double totalTime;                    /* save the totalTime */
   rtclock_t totalTimeClock;            /* time clock for the totalTime */
@@ -429,9 +434,13 @@ typedef struct LINEAR_SYSTEM_DATA
   modelica_boolean solved;             /* true if solved in current step */
   modelica_boolean failed;             /* true if failed while last try with lapack */
 
+  modelica_boolean logActive;          /* Specifies whether LOG_XXX should print for this system.
+                                          false if `-lv_system` is specified but equationIndex is not in the list, else true */
+
   // ToDo: Gather information from all threads if in parallel region
   /* statistics */
   unsigned long numberOfCall;          /* number of solving calls of this system */
+  unsigned long numberOfFailures;      /* number of times solving calls of this system failed */
   unsigned long numberOfJEval;         /* number of jacobian evaluations of this system */
   double totalTime;                    /* save the totalTime */
   rtclock_t totalTimeClock;            /* time clock for the totalTime */
@@ -459,6 +468,9 @@ typedef struct MIXED_SYSTEM_DATA
 
   modelica_integer method;             /* not used yet */
   modelica_boolean solved;             /* true if solved in current step */
+
+  modelica_boolean logActive;          /* Specifies whether LOG_XXX should print for this system.
+                                          false if `-lv_system` is specified but equationIndex is not in the list, else true */
 } MIXED_SYSTEM_DATA;
 #else
 typedef void* MIXED_SYSTEM_DATA;
@@ -693,6 +705,7 @@ typedef struct SIMULATION_INFO
 
   double loggingTimeRecord[2];         /* Time interval in which logging is active. Only used if useLoggingTime=1 */
   int useLoggingTime;                  /* 0 if logging is currently disabled, 1 if enabled */
+  unsigned long maxWarnDisplays;       /* Maximum number repeating warnings are displayed */
 
   LINEAR_SOLVER lsMethod;              /* linear solver */
   LINEAR_SPARSE_SOLVER lssMethod;      /* linear sparse solver */
@@ -777,10 +790,9 @@ typedef struct SIMULATION_INFO
 
   ANALYTIC_JACOBIAN* analyticJacobians; // TODO Only store information for Jacobian used by integrator here
 
-  NONLINEAR_SYSTEM_DATA* nonlinearSystemData;
+  NONLINEAR_SYSTEM_DATA* nonlinearSystemData; /* Array of non-linear systems */
 
-  LINEAR_SYSTEM_DATA* linearSystemData;
-  int currentLinearSystemIndex;
+  LINEAR_SYSTEM_DATA* linearSystemData;       /* Array of linear systems */
 
   MIXED_SYSTEM_DATA* mixedSystemData;
 
