@@ -434,10 +434,10 @@ void TextAnnotation::drawAnnotation(QPainter *painter)
     painter->setFont(font);
   }
   /* Try to get the elided text if calculated font size <= Helper::minimumTextFontSize
-   * OR if font size is absolute.
+   * OR if font size is absolute and text is not multiline.
    */
   QString textToDraw = textString;
-  if (absMappedBoundingRect.width() > 1 && ((mFontSize <= 0 && painter->font().pointSizeF() <= Helper::minimumTextFontSize) || mFontSize > 0)) {
+  if (absMappedBoundingRect.width() > 1 && ((mFontSize <= 0 && painter->font().pointSizeF() <= Helper::minimumTextFontSize) || (mFontSize > 0 && !Utilities::isMultiline(textString)))) {
     QFontMetrics fontMetrics(painter->font());
     textToDraw = fontMetrics.elidedText(textString, Qt::ElideRight, absMappedBoundingRect.width());
     // if we get "..." i.e., QChar(0x2026) as textToDraw then don't draw anything
