@@ -566,7 +566,7 @@ void UpdateElementAttributesCommand::updateComponentModifiers(Element *pComponen
   for (modifiersIterator = modifiers.begin(); modifiersIterator != modifiers.end(); ++modifiersIterator) {
     QString modifierName = QString(pComponent->getName()).append(".").append(modifiersIterator.key());
     QString modifierValue = modifiersIterator.value();
-    if (MainWindow::instance()->getOMCProxy()->setElementModifierValue(modelName, modifierName, modifierValue)) {
+    if (MainWindow::instance()->getOMCProxy()->setElementModifierValueOld(modelName, modifierName, modifierValue)) {
       modifierValueChanged = true;
     }
   }
@@ -606,7 +606,7 @@ void UpdateElementParametersCommand::redoInternal()
     for (componentModifier = mNewComponentModifiersMap.begin(); componentModifier != mNewComponentModifiersMap.end(); ++componentModifier) {
       QString modifierValue = componentModifier.value();
       QString modifierKey = QString(mpComponent->getName()).append(".").append(componentModifier.key());
-      pOMCProxy->setElementModifierValue(className, modifierKey, modifierValue);
+      pOMCProxy->setElementModifierValueOld(className, modifierKey, modifierValue);
     }
     // we want to load modifiers even if they are loaded already
     mpComponent->getElementInfo()->setModifiersLoaded(false);
@@ -618,7 +618,7 @@ void UpdateElementParametersCommand::redoInternal()
     QMap<QString, QString>::iterator componentExtendsModifier;
     for (componentExtendsModifier = mNewComponentExtendsModifiersMap.begin(); componentExtendsModifier != mNewComponentExtendsModifiersMap.end(); ++componentExtendsModifier) {
       QString modifierValue = componentExtendsModifier.value();
-      pOMCProxy->setExtendsModifierValue(className, inheritedClassName, componentExtendsModifier.key(), modifierValue);
+      pOMCProxy->setExtendsModifierValueOld(className, inheritedClassName, componentExtendsModifier.key(), modifierValue);
     }
     mpComponent->getGraphicsView()->getModelWidget()->fetchExtendsModifiers(inheritedClassName);
   }
@@ -641,7 +641,7 @@ void UpdateElementParametersCommand::undo()
     for (componentModifier = mOldComponentModifiersMap.begin(); componentModifier != mOldComponentModifiersMap.end(); ++componentModifier) {
       QString modifierValue = componentModifier.value();
       QString modifierKey = QString(mpComponent->getName()).append(".").append(componentModifier.key());
-      pOMCProxy->setElementModifierValue(className, modifierKey, modifierValue);
+      pOMCProxy->setElementModifierValueOld(className, modifierKey, modifierValue);
     }
     // we want to load modifiers even if they are loaded already
     mpComponent->getElementInfo()->setModifiersLoaded(false);
@@ -655,7 +655,7 @@ void UpdateElementParametersCommand::undo()
     QMap<QString, QString>::iterator componentExtendsModifier;
     for (componentExtendsModifier = mOldComponentExtendsModifiersMap.begin(); componentExtendsModifier != mOldComponentExtendsModifiersMap.end(); ++componentExtendsModifier) {
       QString modifierValue = componentExtendsModifier.value();
-      pOMCProxy->setExtendsModifierValue(className, inheritedClassName, componentExtendsModifier.key(), modifierValue);
+      pOMCProxy->setExtendsModifierValueOld(className, inheritedClassName, componentExtendsModifier.key(), modifierValue);
     }
     mpComponent->getGraphicsView()->getModelWidget()->fetchExtendsModifiers(inheritedClassName);
   }
@@ -1645,29 +1645,45 @@ void OMSimulatorUndoCommand::switchToEditedModelWidget()
   }
 }
 
+/*!
+ * \brief OMCUndoCommand::OMCUndoCommand
+ * Undo command used with the instance API.
+ * \param pLibraryTreeItem
+ * \param oldModelInfo
+ * \param newModelInfo
+ * \param commandText
+ * \param pParent
+ */
 OMCUndoCommand::OMCUndoCommand(LibraryTreeItem *pLibraryTreeItem, const ModelInfo &oldModelInfo, const ModelInfo &newModelInfo, const QString &commandText, UndoCommand *pParent)
   : UndoCommand(pParent)
 {
   mpLibraryTreeItem = pLibraryTreeItem;
-  mOldModelText = mpLibraryTreeItem->getModelWidget()->getModelTextForOMCUndoCommand();
+  LibraryTreeModel *pLibraryTreeModel = MainWindow::instance()->getLibraryWidget()->getLibraryTreeModel();
+  // get the containing parent LibraryTreeItem
+  mpParentContainingLibraryTreeItem = pLibraryTreeModel->getContainingFileParentLibraryTreeItem(mpLibraryTreeItem);
+  mOldModelText = mpParentContainingLibraryTreeItem->getClassText(pLibraryTreeModel);
   mOldModelInfo = oldModelInfo;
-  mNewModelText = MainWindow::instance()->getOMCProxy()->listFile(pLibraryTreeItem->getNameStructure());
+  mNewModelText = MainWindow::instance()->getOMCProxy()->listFile(mpParentContainingLibraryTreeItem->getNameStructure());
   mNewModelInfo = newModelInfo;
-  mUndoDoneOnce = false;
   setText(commandText);
 }
 
+/*!
+ * \brief OMCUndoCommand::redoInternal
+ * Loads the new model text and redraws the model.
+ */
 void OMCUndoCommand::redoInternal()
 {
-  if (mUndoDoneOnce) {
-    MainWindow::instance()->getOMCProxy()->loadString(mNewModelText, mpLibraryTreeItem->getFileName());
-  }
+  MainWindow::instance()->getOMCProxy()->loadString(mNewModelText, mpParentContainingLibraryTreeItem->getFileName());
   mpLibraryTreeItem->getModelWidget()->reDrawModelWidget(mNewModelInfo);
 }
 
+/*!
+ * \brief OMCUndoCommand::undo
+ * Loads the old model text and redraws the model.
+ */
 void OMCUndoCommand::undo()
 {
-  MainWindow::instance()->getOMCProxy()->loadString(mOldModelText, mpLibraryTreeItem->getFileName());
-  mUndoDoneOnce = true;
+  MainWindow::instance()->getOMCProxy()->loadString(mOldModelText, mpParentContainingLibraryTreeItem->getFileName());
   mpLibraryTreeItem->getModelWidget()->reDrawModelWidget(mOldModelInfo);
 }
