@@ -56,7 +56,9 @@
 #include <QStatusBar>
 #include <QListWidget>
 #include <QMdiArea>
+#ifndef OM_OMEDIT_ENABLE_QTWEBENGINE
 #include <QtWebKit>
+#endif
 #include <QtXmlPatterns>
 #include <QSplitter>
 #include <QUndoStack>
@@ -246,7 +248,6 @@ public:
   QAction* getFlipVerticalAction() {return mpFlipVerticalAction;}
   bool performElementCreationChecks(LibraryTreeItem *pLibraryTreeItem, QString *name, QString *defaultPrefix);
   static ModelInstance::Component* createModelInstanceComponent(ModelInstance::Model *pModelInstance, const QString &name, const QString &className);
-  static void setModifiers(const QString &modelName, const QString &name, QString modifierNames, const ModelInstance::Modifier modifier);
   bool addComponent(QString className, QPointF position);
   void addComponentToView(QString name, LibraryTreeItem *pLibraryTreeItem, QString annotation, QPointF position,
                           ElementInfo *pComponentInfo, bool addObject, bool openingClass, bool emitComponentAdded);
@@ -536,37 +537,6 @@ public:
   bool mPrimitivesVisible;
 };
 
-class MimeData : public QMimeData
-{
-  Q_OBJECT
-public:
-  MimeData() : QMimeData()
-  {
-    mComponents.clear();
-    mConnections.clear();
-    mShapes.clear();
-  }
-  void addComponent(Element *pComponent) {mComponents.append(pComponent);}
-  QList<Element*> getComponents() const {return mComponents;}
-  void addModifier(ModelInstance::Modifier modifier) {mModifiers.append(modifier);}
-  QList<ModelInstance::Modifier> getModifiers() const {return mModifiers;}
-  void addConnection(LineAnnotation *pConnectionLineAnnotation) {mConnections.append(pConnectionLineAnnotation);}
-  QList<LineAnnotation*> getConnections() const {return mConnections;}
-  void addShape(ShapeAnnotation *pShapeAnnotation) {mShapes.append(pShapeAnnotation);}
-  QList<ShapeAnnotation*> getShapes() const {return mShapes;}
-private:
-  QList<Element*> mComponents;
-  QList<ModelInstance::Modifier> mModifiers;
-  QList<LineAnnotation*> mConnections;
-  QList<ShapeAnnotation*> mShapes;
-  // QMimeData interface
-public:
-  virtual QStringList formats() const override
-  {
-    return QStringList() << "text/plain" << Helper::cutCopyPasteFormat;
-  }
-};
-
 class ModelWidgetContainer;
 class ModelicaHighlighter;
 class CompositeModelHighlighter;
@@ -606,7 +576,6 @@ public:
   QMap<QString, QString> getDerivedClassModifiersMap();
 
   bool isNewApi();
-  QString getModelTextForOMCUndoCommand();
   void addDependsOnModel(const QString &dependsOnModel);
   void clearDependsOnModels() {mDependsOnModelsList.clear();}
 
