@@ -34,12 +34,6 @@
 
 //! @brief Contains functions used for parsing results obtained from OpenModelica Compiler.
 
-#define ANTLR4CPP_STATIC
-#include "antlr4-runtime.h"
-#include "modelicaLexer.h"
-#include "modelicaParser.h"
-#include "modelicaBaseListener.h"
-
 #include "StringHandler.h"
 #include "Helper.h"
 #include "Utilities.h"
@@ -50,9 +44,7 @@
 #include <QFileDialog>
 #include <QTextCodec>
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
 #define toAscii toLatin1
-#endif
 
 
 QString StringHandler::mLastOpenDir;
@@ -700,7 +692,7 @@ QComboBox* StringHandler::getEndArrowComboBox()
  * Returns the font weight
  * \return
  */
-int StringHandler::getFontWeight(QList<StringHandler::TextStyle> styleList)
+int StringHandler::getFontWeight(QVector<StringHandler::TextStyle> styleList)
 {
   foreach (StringHandler::TextStyle textStyle, styleList) {
     if (textStyle == StringHandler::TextStyleBold) {
@@ -716,7 +708,7 @@ int StringHandler::getFontWeight(QList<StringHandler::TextStyle> styleList)
  * Returns true if font is italic.
  * \return
  */
-bool StringHandler::getFontItalic(QList<StringHandler::TextStyle> styleList)
+bool StringHandler::getFontItalic(QVector<StringHandler::TextStyle> styleList)
 {
   foreach (StringHandler::TextStyle textStyle, styleList) {
     if (textStyle == StringHandler::TextStyleItalic) {
@@ -732,7 +724,7 @@ bool StringHandler::getFontItalic(QList<StringHandler::TextStyle> styleList)
  * Returns true is font is underline.
  * \return
  */
-bool StringHandler::getFontUnderline(QList<StringHandler::TextStyle> styleList)
+bool StringHandler::getFontUnderline(QVector<TextStyle> styleList)
 {
   foreach (StringHandler::TextStyle textStyle, styleList) {
     if (textStyle == StringHandler::TextStyleUnderLine) {
@@ -801,6 +793,25 @@ QString StringHandler::getTextAlignmentString(StringHandler::TextAlignment align
   }
 }
 
+/*!
+ * \brief StringHandler::getTextStyleType
+ * Returns the text style type.
+ * \param textStyle
+ * \return
+ */
+StringHandler::TextStyle StringHandler::getTextStyleType(QString textStyle)
+{
+  if (textStyle.compare("TextStyle.Bold") == 0) {
+    return StringHandler::TextStyleBold;
+  } else if (textStyle.compare("TextStyle.Italic") == 0) {
+    return StringHandler::TextStyleItalic;
+  } else if (textStyle.compare("TextStyle.UnderLine") == 0) {
+    return StringHandler::TextStyleUnderLine;
+  } else {
+    return StringHandler::TextStyleBold;
+  }
+}
+
 /*!
  * \brief StringHandler::getTextStyleString
  * \param textStyle
@@ -1306,17 +1317,7 @@ QString StringHandler::getSaveFileName(QWidget* parent, const QString &caption,
   }
 
   if (!fileName.isEmpty()) {
-    /* Qt is not reallllyyyy platform independent :(
-     * In older versions of Qt QFileDialog::getSaveFileName doesn't return file extension on Linux.
-     * But it works fine in Qt 4.8.
-     */
     QFileInfo fileInfo(fileName);
-#if defined(Q_OS_LINUX) && QT_VERSION < 0x040800
-    if (fileInfo.suffix() == QString(""))
-      fileName.append(".").append(defaultSuffix);
-#else
-    Q_UNUSED(defaultSuffix);
-#endif
     StringHandler::setLastOpenDirectory(fileInfo.absolutePath());
   }
   return fileName;
@@ -1582,7 +1583,6 @@ QStringList StringHandler::makeVariableParts(QString variable)
 }
 
 #include <iostream>
-using namespace std;
 
 QStringList StringHandler::makeVariablePartsWithInd(QString variable)
 {
@@ -1649,29 +1649,6 @@ bool StringHandler::naturalSort(const QString &s1, const QString &s2) {
   }
 }
 
-QString StringHandler::cleanResultVariable(const QString &variable)
-{
-  QString str = variable;
-  if (str.startsWith("der(")) {
-    str.chop((str.lastIndexOf("der(")/4)+1);
-    str = str.mid(str.lastIndexOf("der(") + 4);
-  } else if (str.startsWith("previous(")) {
-    str.chop((str.lastIndexOf("previous(")/9)+1);
-    str = str.mid(str.lastIndexOf("previous(") + 9);
-  } else {
-    // do nothing
-  }
-  return str;
-}
-
-bool StringHandler::naturalSortForResultVariables(const QString &s1, const QString &s2)
-{
-  QString s3 = StringHandler::cleanResultVariable(s1);
-  QString s4 = StringHandler::cleanResultVariable(s2);
-
-  return StringHandler::naturalSort(s3, s4);
-}
-
 #if defined(_WIN32)
 /*!
  * \brief StringHandler::simulationProcessEnvironment
@@ -1727,24 +1704,6 @@ QString StringHandler::getSimulationMessageTypeString(StringHandler::SimulationM
   }
 }
 
-QColor StringHandler::getSimulationMessageTypeColor(StringHandler::SimulationMessageType type)
-{
-  switch (type) {
-    case StringHandler::OMEditInfo:
-      return Qt::blue;
-    case StringHandler::SMWarning:
-    case StringHandler::Error:
-    case StringHandler::Assert:
-      return Qt::red;
-    case StringHandler::Debug:
-    case StringHandler::Info:
-    case StringHandler::Unknown:
-    default:
-      return Qt::black;
-      break;
-  }
-}
-
 /*!
  * \brief StringHandler::makeClassNameRelative
  * Removes the first characters matching with droppedClassName from draggedClassName.
@@ -1974,40 +1933,6 @@ QString StringHandler::number(double value, QString hint, char format, int preci
   }
 }
 
-static std::string cmt = "";
-
-class ModelicaCommentListener : public openmodelica::modelicaBaseListener {
-    void exitComment(openmodelica::modelicaParser::CommentContext *ctx) override {
-        cmt = ctx->getText();
-    }
-};
-
-/*!
- * \brief StringHandler::getModelicaComment
- * Helper for QString::getModelicaComment
- * \param element
- * \return comment
- */
-QString StringHandler::getModelicaComment(QString element)
-{
-  cmt = "";
-  std::string s = element.toStdString();
-  antlr4::ANTLRInputStream input(s);
-  openmodelica::modelicaLexer lexer(&input);
-  antlr4::CommonTokenStream tokens(&lexer);
-  openmodelica::modelicaParser parser(&tokens);
-  antlr4::tree::ParseTree* tree = parser.argument();
-  ModelicaCommentListener listener;
-  antlr4::tree::ParseTreeWalker::DEFAULT.walk(&listener, tree);
-  if (cmt.size() > 1)
-  {
-    QString q;
-    q = q.fromStdString(cmt);
-    return removeFirstLastQuotes(q);
-  }
-  return element;
-}
-
 /*!
  * \brief StringHandler::convertSemVertoReadableString
  * Converts the semver to user friendly string.
