@@ -38,6 +38,7 @@
 #include "Model.h"
 #include "ssd/Tags.h"
 
+#include <sstream>
 
 int oms::cvode_rhs(realtype t, N_Vector y, N_Vector ydot, void* user_data)
 {
@@ -134,16 +135,23 @@ oms_status_enu_t oms::SystemSC::setSolverMethod(std::string solver)
 
 oms_status_enu_t oms::SystemSC::exportToSSD_SimulationInformation(pugi::xml_node& node) const
 {
+  std::ostringstream ssAbsoluteTolerance, ssRelativeTolerance, ssMinimumStepSize, ssMaximumStepSize, ssInitialStepSize;
+  ssAbsoluteTolerance << absoluteTolerance;
+  ssRelativeTolerance << relativeTolerance;
+  ssMinimumStepSize << minimumStepSize;
+  ssMaximumStepSize << maximumStepSize;
+  ssInitialStepSize << initialStepSize;
+
   /* ssd:SimulationInformation should be added as vendor specific annotations from Version 1.0 */
   pugi::xml_node node_simulation_information = node.append_child(oms::ssp::Version1_0::simulation_information);
 
   pugi::xml_node node_solver = node_simulation_information.append_child(oms::ssp::Version1_0::VariableStepSolver);
   node_solver.append_attribute("description") = getSolverName().c_str();
-  node_solver.append_attribute("absoluteTolerance") = std::to_string(absoluteTolerance).c_str();
-  node_solver.append_attribute("relativeTolerance") = std::to_string(relativeTolerance).c_str();
-  node_solver.append_attribute("minimumStepSize") = std::to_string(minimumStepSize).c_str();
-  node_solver.append_attribute("maximumStepSize") = std::to_string(maximumStepSize).c_str();
-  node_solver.append_attribute("initialStepSize") = std::to_string(initialStepSize).c_str();
+  node_solver.append_attribute("absoluteTolerance") = ssAbsoluteTolerance.str().c_str();
+  node_solver.append_attribute("relativeTolerance") = ssRelativeTolerance.str().c_str();
+  node_solver.append_attribute("minimumStepSize") = ssMinimumStepSize.str().c_str();
+  node_solver.append_attribute("maximumStepSize") = ssMaximumStepSize.str().c_str();
+  node_solver.append_attribute("initialStepSize") = ssInitialStepSize.str().c_str();
 
   return oms_status_ok;
 }
@@ -195,8 +203,8 @@ oms_status_enu_t oms::SystemSC::instantiate()
     {
       fmus.push_back(dynamic_cast<ComponentFMUME*>(component.second));
 
-      callEventUpdate.push_back(fmi2_false);
-      terminateSimulation.push_back(fmi2_false);
+      callEventUpdate.push_back(fmi2False);
+      terminateSimulation.push_back(fmi2False);
       nStates.push_back(fmus.back()->getNumberOfContinuousStates());
       n_states += nStates.back();
       nEventIndicators.push_back(fmus.back()->getNumberOfEventIndicators());
@@ -299,7 +307,7 @@ oms_status_enu_t oms::SystemSC::initialize()
     if (!solverData.cvode.abstol) logError("SUNDIALS_ERROR: N_VNew_Serial() failed - returned NULL pointer");
     for (int j=0, k=0; j < fmus.size(); ++j)
       for (size_t i=0; i < nStates[j]; ++i, ++k)
-        NV_Ith_S(solverData.cvode.abstol, k) = 0.01*relativeTolerance*states_nominal[j][i];
+        NV_Ith_S(solverData.cvode.abstol, k) = 0.01*absoluteTolerance*states_nominal[j][i];
     //N_VPrint_Serial(solverData.cvode.abstol);
 
     // Call CVodeCreate to create the solver memory and specify the
@@ -335,28 +343,26 @@ oms_status_enu_t oms::SystemSC::initialize()
     flag = CVodeSetLinearSolver(solverData.cvode.mem, solverData.cvode.linSol, solverData.cvode.J);
     if (flag < 0) logError("SUNDIALS_ERROR: CVDense() failed with flag = " + std::to_string(flag));
 
-    const fmi2_real_t stopTime = 1.0;
-    double max_h = (stopTime - time) / 10.0;
-    logInfo("maximum step size for '" + std::string(getFullCref()) + "': " + std::to_string(max_h));
-    flag = CVodeSetMaxStep(solverData.cvode.mem, max_h);
+    logInfo("maximum step size for '" + std::string(getFullCref()) + "': " + std::to_string(maximumStepSize));
+    flag = CVodeSetMaxStep(solverData.cvode.mem, maximumStepSize);
     if (flag < 0) logError("SUNDIALS_ERROR: CVodeSetMaxStep() failed with flag = " + std::to_string(flag));
 
     // further settings from cpp runtime
-    flag = CVodeSetInitStep(solverData.cvode.mem, 1e-6);        // INITIAL STEPSIZE
+    flag = CVodeSetInitStep(solverData.cvode.mem, initialStepSize);  // INITIAL STEPSIZE
     if (flag < 0) logError("SUNDIALS_ERROR: CVodeSetInitStep() failed with flag = " + std::to_string(flag));
-    flag = CVodeSetMaxOrd(solverData.cvode.mem, 5);             // MAXIMUM ORDER
+    flag = CVodeSetMaxOrd(solverData.cvode.mem, 5);                  // MAXIMUM ORDER
     if (flag < 0) logError("SUNDIALS_ERROR: CVodeSetMaxOrd() failed with flag = " + std::to_string(flag));
-    flag = CVodeSetMaxConvFails(solverData.cvode.mem, 100);     // MAXIMUM NUMBER OF NONLINEAR CONVERGENCE FAILURES
+    flag = CVodeSetMaxConvFails(solverData.cvode.mem, 100);          // MAXIMUM NUMBER OF NONLINEAR CONVERGENCE FAILURES
     if (flag < 0) logError("SUNDIALS_ERROR: CVodeSetMaxConvFails() failed with flag = " + std::to_string(flag));
-    flag = CVodeSetStabLimDet(solverData.cvode.mem, true);      // STABILITY DETECTION
+    flag = CVodeSetStabLimDet(solverData.cvode.mem, true);           // STABILITY DETECTION
     if (flag < 0) logError("SUNDIALS_ERROR: CVodeSetStabLimDet() failed with flag = " + std::to_string(flag));
-    flag = CVodeSetMinStep(solverData.cvode.mem, 1e-12);        // MINIMUM STEPSIZE
+    flag = CVodeSetMinStep(solverData.cvode.mem, minimumStepSize);   // MINIMUM STEPSIZE
     if (flag < 0) logError("SUNDIALS_ERROR: CVodeSetMinStep() failed with flag = " + std::to_string(flag));
-    flag = CVodeSetMaxNonlinIters(solverData.cvode.mem, 5);     // MAXIMUM NUMBER OF ITERATIONS
+    flag = CVodeSetMaxNonlinIters(solverData.cvode.mem, 5);          // MAXIMUM NUMBER OF ITERATIONS
     if (flag < 0) logError("SUNDIALS_ERROR: CVodeSetMaxNonlinIters() failed with flag = " + std::to_string(flag));
-    flag = CVodeSetMaxErrTestFails(solverData.cvode.mem, 100);  // MAXIMUM NUMBER OF ERROR TEST FAILURES
+    flag = CVodeSetMaxErrTestFails(solverData.cvode.mem, 100);       // MAXIMUM NUMBER OF ERROR TEST FAILURES
     if (flag < 0) logError("SUNDIALS_ERROR: CVodeSetMaxErrTestFails() failed with flag = " + std::to_string(flag));
-    flag = CVodeSetMaxNumSteps(solverData.cvode.mem, 1000);     // MAXIMUM NUMBER OF STEPS
+    flag = CVodeSetMaxNumSteps(solverData.cvode.mem, 1000);          // MAXIMUM NUMBER OF STEPS
     if (flag < 0) logError("SUNDIALS_ERROR: CVodeSetMaxNumSteps() failed with flag = " + std::to_string(flag));
   }
 
@@ -478,25 +484,25 @@ oms_status_enu_t oms::SystemSC::reset()
 oms_status_enu_t oms::SystemSC::doStep()
 {
   const double hdef = maximumStepSize;
-  fmi2_real_t tlast = time;
-  fmi2_real_t tnext = time + hdef;
-  fmi2_status_t fmistatus;
+  fmi2Real tlast = time;
+  fmi2Real tnext = time + hdef;
+  fmi2Status fmistatus;
   oms_status_enu_t status;
 
   // event handling
   for (int i=0; i < fmus.size(); ++i)
   {
-    fmistatus = fmi2_import_set_time(fmus[i]->getFMU(), time);
-    if (fmi2_status_ok != fmistatus) logError_FMUCall("fmi2_import_set_time", fmus[i]);
+    fmistatus = fmi2_setTime(fmus[i]->getFMU(), time);
+    if (fmi2OK != fmistatus) logError_FMUCall("fmi2_setTime", fmus[i]);
 
     // swap event_indicators and event_indicators_prev
     {
-      fmi2_real_t *temp = event_indicators[i];
+      fmi2Real *temp = event_indicators[i];
       event_indicators[i] = event_indicators_prev[i];
       event_indicators_prev[i] = temp;
 
-      fmistatus = fmi2_import_get_event_indicators(fmus[i]->getFMU(), event_indicators[i], nEventIndicators[i]);
-      if (fmi2_status_ok != fmistatus) logError_FMUCall("fmi2_import_get_event_indicators", fmus[i]);
+      fmistatus = fmi2_getEventIndicators(fmus[i]->getFMU(), event_indicators[i], nEventIndicators[i]);
+      if (fmi2OK != fmistatus) logError_FMUCall("fmi2_getEventIndicators", fmus[i]);
     }
 
     // check if an event indicator has triggered
@@ -516,16 +522,16 @@ oms_status_enu_t oms::SystemSC::doStep()
       logDebug("Event detected in FMU \"" + std::string(fmus[i]->getFullCref()) + "\" at time=" + std::to_string(time));
 
       // emit the left limit of the event (if it hasn't already been emitted)
-      if (Flags::EmitEvents() && isTopLevelSystem())
+      if (isTopLevelSystem())
         getModel().emit(time, false);
 
-      fmistatus = fmi2_import_enter_event_mode(fmus[i]->getFMU());
-      if (fmi2_status_ok != fmistatus) logError_FMUCall("fmi2_import_enter_event_mode", fmus[i]);
+      fmistatus = fmi2_enterEventMode(fmus[i]->getFMU());
+      if (fmi2OK != fmistatus) logError_FMUCall("fmi2_enterEventMode", fmus[i]);
 
       fmus[i]->doEventIteration();
 
-      fmistatus = fmi2_import_enter_continuous_time_mode(fmus[i]->getFMU());
-      if (fmi2_status_ok != fmistatus) logError_FMUCall("fmi2_import_enter_continuous_time_mode", fmus[i]);
+      fmistatus = fmi2_enterContinuousTimeMode(fmus[i]->getFMU());
+      if (fmi2OK != fmistatus) logError_FMUCall("fmi2_enterContinuousTimeMode", fmus[i]);
       if (nStates[i] > 0)
       {
         status = fmus[i]->getContinuousStates(states[i]);
@@ -549,7 +555,7 @@ oms_status_enu_t oms::SystemSC::doStep()
 
       // emit the right limit of the event
       updateInputs(eventGraph);
-      if (Flags::EmitEvents() && isTopLevelSystem())
+      if (isTopLevelSystem())
         getModel().emit(time, true);
 
       // restart event iteration from the beginning
@@ -563,7 +569,7 @@ oms_status_enu_t oms::SystemSC::doStep()
   }
 
   // calculate step size
-  fmi2_real_t hcur = tnext - tlast;
+  fmi2Real hcur = tnext - tlast;
   const double stopTime = getModel().getStopTime();
   if (tnext > stopTime - hcur / 1e16)
   {
@@ -626,8 +632,8 @@ oms_status_enu_t oms::SystemSC::doStep()
   // step is complete
   for (int i=0; i < fmus.size(); ++i)
   {
-    fmistatus = fmi2_import_completed_integrator_step(fmus[i]->getFMU(), fmi2_true, &callEventUpdate[i], &terminateSimulation[i]);
-    if (fmi2_status_ok != fmistatus) return logError_FMUCall("fmi2_import_completed_integrator_step", fmus[i]);
+    fmistatus = fmi2_completedIntegratorStep(fmus[i]->getFMU(), fmi2True, &callEventUpdate[i], &terminateSimulation[i]);
+    if (fmi2OK != fmistatus) return logError_FMUCall("fmi2_completedIntegratorStep", fmus[i]);
   }
 
   updateInputs(simulationGraph); //pass the continuousTimeMode dependency graph which involves only connections of type Real
@@ -643,7 +649,7 @@ oms_status_enu_t oms::SystemSC::stepUntil(double stopTime)
   const double startTime=time;
 
   if (Flags::ProgressBar())
-    logInfo("stepUntil [" + std::to_string(startTime) + "; " + std::to_string(stopTime) + "]");
+    logInfo("step SC system [" + std::to_string(startTime) + "; " + std::to_string(stopTime) + "] with step size [" + std::to_string(initialStepSize) + "; " + std::to_string(minimumStepSize) + "; " + std::to_string(maximumStepSize) + "]");
 
   // main simulation loop
   oms_status_enu_t status = oms_status_ok;
@@ -675,8 +681,8 @@ oms_status_enu_t oms::SystemSC::updateInputs(DirectedGraph& graph)
       switch (component.second->getType())
       {
         case oms_component_fmu:
-          if (fmi2_status_ok != fmi2_import_set_time(dynamic_cast<ComponentFMUME*>(component.second)->getFMU(), time))
-            logError_FMUCall("fmi2_import_set_time", dynamic_cast<ComponentFMUME*>(component.second));
+          if (fmi2OK != fmi2_setTime(dynamic_cast<ComponentFMUME*>(component.second)->getFMU(), time))
+            logError_FMUCall("fmi2_setTime", dynamic_cast<ComponentFMUME*>(component.second));
           break;
         case oms_component_table:
           dynamic_cast<ComponentTable*>(component.second)->stepUntil(time);
@@ -688,20 +694,28 @@ oms_status_enu_t oms::SystemSC::updateInputs(DirectedGraph& graph)
   }
 
   // input := output
-  const std::vector< oms_ssc_t >& sortedConnections = graph.getSortedConnections();
-  updateAlgebraicLoops(sortedConnections);
+  const std::vector< scc_t >& sortedConnections = graph.getSortedConnections();
+  updateAlgebraicLoops(sortedConnections, graph);
 
   for(int i=0; i<sortedConnections.size(); i++)
   {
-    if (sortedConnections[i].size() == 1)
+    if (!sortedConnections[i].thisIsALoop)
     {
-      int output = sortedConnections[i][0].first;
-      int input = sortedConnections[i][0].second;
+      int output = sortedConnections[i].connections[0].first;
+      int input = sortedConnections[i].connections[0].second;
 
       if (graph.getNodes()[input].getType() == oms_signal_type_real)
       {
         double value = 0.0;
         if (oms_status_ok != getReal(graph.getNodes()[output].getName(), value)) return oms_status_error;
+        /* check for unit conversion and suppressUnitConversion and set the value multiplied by factor,
+         * by default, factor = 1.0, (e.g) mm to m will be (factor*value) => (10^-3 * value)
+        */
+        if (sortedConnections[i].suppressUnitConversion)
+          value = value;
+        else
+          value = sortedConnections[i].factor*value;
+
         if (oms_status_ok != setReal(graph.getNodes()[input].getName(), value)) return oms_status_error;
       }
       else if (graph.getNodes()[input].getType() == oms_signal_type_integer || graph.getNodes()[input].getType() == oms_signal_type_enum)
